Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(193)

Unified Diff: third_party/WebKit/Source/core/workers/MainThreadWorkletGlobalScope.cpp

Issue 2868413005: Worklet: Introduce WorkletOptions for addModule() (Closed)
Patch Set: add TODO comments Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/workers/MainThreadWorkletGlobalScope.cpp
diff --git a/third_party/WebKit/Source/core/workers/MainThreadWorkletGlobalScope.cpp b/third_party/WebKit/Source/core/workers/MainThreadWorkletGlobalScope.cpp
index daaefd86401e725b90794ff5740b42da68f2a005..bb71248f0b1a58ae06bf54273ad6271724340cbb 100644
--- a/third_party/WebKit/Source/core/workers/MainThreadWorkletGlobalScope.cpp
+++ b/third_party/WebKit/Source/core/workers/MainThreadWorkletGlobalScope.cpp
@@ -51,6 +51,7 @@ WorkerThread* MainThreadWorkletGlobalScope::GetThread() const {
// https://drafts.css-houdini.org/worklets/#fetch-and-invoke-a-worklet-script
void MainThreadWorkletGlobalScope::FetchAndInvokeScript(
const KURL& module_url_record,
+ WebURLRequest::FetchCredentialsMode credentials_mode,
WorkletPendingTasks* pending_tasks) {
DCHECK(IsMainThread());
// Step 1: "Let insideSettings be the workletGlobalScope's associated
@@ -58,7 +59,8 @@ void MainThreadWorkletGlobalScope::FetchAndInvokeScript(
// Step 2: "Let script by the result of fetch a worklet script given
// moduleURLRecord, moduleResponsesMap, credentialOptions, outsideSettings,
// and insideSettings when it asynchronously completes."
// TODO(nhiroki): Replace this with module script loading.
WorkletScriptLoader* script_loader =
WorkletScriptLoader::Create(GetFrame()->GetDocument()->Fetcher(), this);
loader_map_.Set(script_loader, pending_tasks);
@@ -58,7 +59,8 @@ void MainThreadWorkletGlobalScope::FetchAndInvokeScript(
// moduleURLRecord, moduleResponsesMap, credentialOptions, outsideSettings,
// and insideSettings when it asynchronously completes."
- // TODO(nhiroki): Replace this with module script loading.
+ // TODO(nhiroki): Replace this with module script loading. Set fetch request's
+ // credentials mode to |credentials_mode|.
WorkletScriptLoader* script_loader =
WorkletScriptLoader::Create(GetFrame()->GetDocument()->Fetcher(), this);

Powered by Google App Engine
This is Rietveld 408576698